"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._1984 import BallBearingAnalysisMethod
    from ._1985 import BallBearingContactCalculation
    from ._1986 import BallBearingRaceContactGeometry
    from ._1987 import DIN7322010Results
    from ._1988 import ForceAtLaminaGroupReportable
    from ._1989 import ForceAtLaminaReportable
    from ._1990 import FrictionModelForGyroscopicMoment
    from ._1991 import InternalClearance
    from ._1992 import ISO14179Settings
    from ._1993 import ISO14179SettingsDatabase
    from ._1994 import ISO14179SettingsPerBearingType
    from ._1995 import ISO153122018Results
    from ._1996 import ISOTR1417912001Results
    from ._1997 import ISOTR141792001Results
    from ._1998 import ISOTR1417922001Results
    from ._1999 import LoadedAbstractSphericalRollerBearingStripLoadResults
    from ._2000 import LoadedAngularContactBallBearingElement
    from ._2001 import LoadedAngularContactBallBearingResults
    from ._2002 import LoadedAngularContactBallBearingRow
    from ._2003 import LoadedAngularContactThrustBallBearingElement
    from ._2004 import LoadedAngularContactThrustBallBearingResults
    from ._2005 import LoadedAngularContactThrustBallBearingRow
    from ._2006 import LoadedAsymmetricSphericalRollerBearingElement
    from ._2007 import LoadedAsymmetricSphericalRollerBearingResults
    from ._2008 import LoadedAsymmetricSphericalRollerBearingRow
    from ._2009 import LoadedAsymmetricSphericalRollerBearingStripLoadResults
    from ._2010 import LoadedAxialThrustCylindricalRollerBearingDutyCycle
    from ._2011 import LoadedAxialThrustCylindricalRollerBearingElement
    from ._2012 import LoadedAxialThrustCylindricalRollerBearingResults
    from ._2013 import LoadedAxialThrustCylindricalRollerBearingRow
    from ._2014 import LoadedAxialThrustNeedleRollerBearingElement
    from ._2015 import LoadedAxialThrustNeedleRollerBearingResults
    from ._2016 import LoadedAxialThrustNeedleRollerBearingRow
    from ._2017 import LoadedBallBearingDutyCycle
    from ._2018 import LoadedBallBearingElement
    from ._2019 import LoadedBallBearingRaceResults
    from ._2020 import LoadedBallBearingResults
    from ._2021 import LoadedBallBearingRow
    from ._2022 import LoadedCrossedRollerBearingElement
    from ._2023 import LoadedCrossedRollerBearingResults
    from ._2024 import LoadedCrossedRollerBearingRow
    from ._2025 import LoadedCylindricalRollerBearingDutyCycle
    from ._2026 import LoadedCylindricalRollerBearingElement
    from ._2027 import LoadedCylindricalRollerBearingResults
    from ._2028 import LoadedCylindricalRollerBearingRow
    from ._2029 import LoadedDeepGrooveBallBearingElement
    from ._2030 import LoadedDeepGrooveBallBearingResults
    from ._2031 import LoadedDeepGrooveBallBearingRow
    from ._2032 import LoadedElement
    from ._2033 import LoadedFourPointContactBallBearingElement
    from ._2034 import LoadedFourPointContactBallBearingRaceResults
    from ._2035 import LoadedFourPointContactBallBearingResults
    from ._2036 import LoadedFourPointContactBallBearingRow
    from ._2037 import LoadedMultiPointContactBallBearingElement
    from ._2038 import LoadedNeedleRollerBearingElement
    from ._2039 import LoadedNeedleRollerBearingResults
    from ._2040 import LoadedNeedleRollerBearingRow
    from ._2041 import LoadedNonBarrelRollerBearingDutyCycle
    from ._2042 import LoadedNonBarrelRollerBearingResults
    from ._2043 import LoadedNonBarrelRollerBearingRow
    from ._2044 import LoadedNonBarrelRollerBearingStripLoadResults
    from ._2045 import LoadedNonBarrelRollerElement
    from ._2046 import LoadedRollerBearingElement
    from ._2047 import LoadedRollerBearingResults
    from ._2048 import LoadedRollerBearingRow
    from ._2049 import LoadedRollerStripLoadResults
    from ._2050 import LoadedRollingBearingRaceResults
    from ._2051 import LoadedRollingBearingResults
    from ._2052 import LoadedRollingBearingRow
    from ._2053 import LoadedSelfAligningBallBearingElement
    from ._2054 import LoadedSelfAligningBallBearingResults
    from ._2055 import LoadedSelfAligningBallBearingRow
    from ._2056 import LoadedSphericalRadialRollerBearingElement
    from ._2057 import LoadedSphericalRollerBearingElement
    from ._2058 import LoadedSphericalRollerRadialBearingResults
    from ._2059 import LoadedSphericalRollerRadialBearingRow
    from ._2060 import LoadedSphericalRollerRadialBearingStripLoadResults
    from ._2061 import LoadedSphericalRollerThrustBearingResults
    from ._2062 import LoadedSphericalRollerThrustBearingRow
    from ._2063 import LoadedSphericalThrustRollerBearingElement
    from ._2064 import LoadedTaperRollerBearingDutyCycle
    from ._2065 import LoadedTaperRollerBearingElement
    from ._2066 import LoadedTaperRollerBearingResults
    from ._2067 import LoadedTaperRollerBearingRow
    from ._2068 import LoadedThreePointContactBallBearingElement
    from ._2069 import LoadedThreePointContactBallBearingResults
    from ._2070 import LoadedThreePointContactBallBearingRow
    from ._2071 import LoadedThrustBallBearingElement
    from ._2072 import LoadedThrustBallBearingResults
    from ._2073 import LoadedThrustBallBearingRow
    from ._2074 import LoadedToroidalRollerBearingElement
    from ._2075 import LoadedToroidalRollerBearingResults
    from ._2076 import LoadedToroidalRollerBearingRow
    from ._2077 import LoadedToroidalRollerBearingStripLoadResults
    from ._2078 import MaximumStaticContactStress
    from ._2079 import MaximumStaticContactStressDutyCycle
    from ._2080 import MaximumStaticContactStressResultsAbstract
    from ._2081 import MaxStripLoadStressObject
    from ._2082 import PermissibleContinuousAxialLoadResults
    from ._2083 import PowerRatingF1EstimationMethod
    from ._2084 import PreloadFactorLookupTable
    from ._2085 import ResultsAtRollerOffset
    from ._2086 import RingForceAndDisplacement
    from ._2087 import RollerAnalysisMethod
    from ._2088 import RollingBearingFrictionCoefficients
    from ._2089 import RollingBearingSpeedResults
    from ._2090 import SMTRibStressResults
    from ._2091 import StressAtPosition
    from ._2092 import ThreePointContactInternalClearance
    from ._2093 import TrackTruncationSafetyFactorResults
else:
    import_structure = {
        "_1984": ["BallBearingAnalysisMethod"],
        "_1985": ["BallBearingContactCalculation"],
        "_1986": ["BallBearingRaceContactGeometry"],
        "_1987": ["DIN7322010Results"],
        "_1988": ["ForceAtLaminaGroupReportable"],
        "_1989": ["ForceAtLaminaReportable"],
        "_1990": ["FrictionModelForGyroscopicMoment"],
        "_1991": ["InternalClearance"],
        "_1992": ["ISO14179Settings"],
        "_1993": ["ISO14179SettingsDatabase"],
        "_1994": ["ISO14179SettingsPerBearingType"],
        "_1995": ["ISO153122018Results"],
        "_1996": ["ISOTR1417912001Results"],
        "_1997": ["ISOTR141792001Results"],
        "_1998": ["ISOTR1417922001Results"],
        "_1999": ["LoadedAbstractSphericalRollerBearingStripLoadResults"],
        "_2000": ["LoadedAngularContactBallBearingElement"],
        "_2001": ["LoadedAngularContactBallBearingResults"],
        "_2002": ["LoadedAngularContactBallBearingRow"],
        "_2003": ["LoadedAngularContactThrustBallBearingElement"],
        "_2004": ["LoadedAngularContactThrustBallBearingResults"],
        "_2005": ["LoadedAngularContactThrustBallBearingRow"],
        "_2006": ["LoadedAsymmetricSphericalRollerBearingElement"],
        "_2007": ["LoadedAsymmetricSphericalRollerBearingResults"],
        "_2008": ["LoadedAsymmetricSphericalRollerBearingRow"],
        "_2009": ["LoadedAsymmetricSphericalRollerBearingStripLoadResults"],
        "_2010": ["LoadedAxialThrustCylindricalRollerBearingDutyCycle"],
        "_2011": ["LoadedAxialThrustCylindricalRollerBearingElement"],
        "_2012": ["LoadedAxialThrustCylindricalRollerBearingResults"],
        "_2013": ["LoadedAxialThrustCylindricalRollerBearingRow"],
        "_2014": ["LoadedAxialThrustNeedleRollerBearingElement"],
        "_2015": ["LoadedAxialThrustNeedleRollerBearingResults"],
        "_2016": ["LoadedAxialThrustNeedleRollerBearingRow"],
        "_2017": ["LoadedBallBearingDutyCycle"],
        "_2018": ["LoadedBallBearingElement"],
        "_2019": ["LoadedBallBearingRaceResults"],
        "_2020": ["LoadedBallBearingResults"],
        "_2021": ["LoadedBallBearingRow"],
        "_2022": ["LoadedCrossedRollerBearingElement"],
        "_2023": ["LoadedCrossedRollerBearingResults"],
        "_2024": ["LoadedCrossedRollerBearingRow"],
        "_2025": ["LoadedCylindricalRollerBearingDutyCycle"],
        "_2026": ["LoadedCylindricalRollerBearingElement"],
        "_2027": ["LoadedCylindricalRollerBearingResults"],
        "_2028": ["LoadedCylindricalRollerBearingRow"],
        "_2029": ["LoadedDeepGrooveBallBearingElement"],
        "_2030": ["LoadedDeepGrooveBallBearingResults"],
        "_2031": ["LoadedDeepGrooveBallBearingRow"],
        "_2032": ["LoadedElement"],
        "_2033": ["LoadedFourPointContactBallBearingElement"],
        "_2034": ["LoadedFourPointContactBallBearingRaceResults"],
        "_2035": ["LoadedFourPointContactBallBearingResults"],
        "_2036": ["LoadedFourPointContactBallBearingRow"],
        "_2037": ["LoadedMultiPointContactBallBearingElement"],
        "_2038": ["LoadedNeedleRollerBearingElement"],
        "_2039": ["LoadedNeedleRollerBearingResults"],
        "_2040": ["LoadedNeedleRollerBearingRow"],
        "_2041": ["LoadedNonBarrelRollerBearingDutyCycle"],
        "_2042": ["LoadedNonBarrelRollerBearingResults"],
        "_2043": ["LoadedNonBarrelRollerBearingRow"],
        "_2044": ["LoadedNonBarrelRollerBearingStripLoadResults"],
        "_2045": ["LoadedNonBarrelRollerElement"],
        "_2046": ["LoadedRollerBearingElement"],
        "_2047": ["LoadedRollerBearingResults"],
        "_2048": ["LoadedRollerBearingRow"],
        "_2049": ["LoadedRollerStripLoadResults"],
        "_2050": ["LoadedRollingBearingRaceResults"],
        "_2051": ["LoadedRollingBearingResults"],
        "_2052": ["LoadedRollingBearingRow"],
        "_2053": ["LoadedSelfAligningBallBearingElement"],
        "_2054": ["LoadedSelfAligningBallBearingResults"],
        "_2055": ["LoadedSelfAligningBallBearingRow"],
        "_2056": ["LoadedSphericalRadialRollerBearingElement"],
        "_2057": ["LoadedSphericalRollerBearingElement"],
        "_2058": ["LoadedSphericalRollerRadialBearingResults"],
        "_2059": ["LoadedSphericalRollerRadialBearingRow"],
        "_2060": ["LoadedSphericalRollerRadialBearingStripLoadResults"],
        "_2061": ["LoadedSphericalRollerThrustBearingResults"],
        "_2062": ["LoadedSphericalRollerThrustBearingRow"],
        "_2063": ["LoadedSphericalThrustRollerBearingElement"],
        "_2064": ["LoadedTaperRollerBearingDutyCycle"],
        "_2065": ["LoadedTaperRollerBearingElement"],
        "_2066": ["LoadedTaperRollerBearingResults"],
        "_2067": ["LoadedTaperRollerBearingRow"],
        "_2068": ["LoadedThreePointContactBallBearingElement"],
        "_2069": ["LoadedThreePointContactBallBearingResults"],
        "_2070": ["LoadedThreePointContactBallBearingRow"],
        "_2071": ["LoadedThrustBallBearingElement"],
        "_2072": ["LoadedThrustBallBearingResults"],
        "_2073": ["LoadedThrustBallBearingRow"],
        "_2074": ["LoadedToroidalRollerBearingElement"],
        "_2075": ["LoadedToroidalRollerBearingResults"],
        "_2076": ["LoadedToroidalRollerBearingRow"],
        "_2077": ["LoadedToroidalRollerBearingStripLoadResults"],
        "_2078": ["MaximumStaticContactStress"],
        "_2079": ["MaximumStaticContactStressDutyCycle"],
        "_2080": ["MaximumStaticContactStressResultsAbstract"],
        "_2081": ["MaxStripLoadStressObject"],
        "_2082": ["PermissibleContinuousAxialLoadResults"],
        "_2083": ["PowerRatingF1EstimationMethod"],
        "_2084": ["PreloadFactorLookupTable"],
        "_2085": ["ResultsAtRollerOffset"],
        "_2086": ["RingForceAndDisplacement"],
        "_2087": ["RollerAnalysisMethod"],
        "_2088": ["RollingBearingFrictionCoefficients"],
        "_2089": ["RollingBearingSpeedResults"],
        "_2090": ["SMTRibStressResults"],
        "_2091": ["StressAtPosition"],
        "_2092": ["ThreePointContactInternalClearance"],
        "_2093": ["TrackTruncationSafetyFactorResults"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "BallBearingAnalysisMethod",
    "BallBearingContactCalculation",
    "BallBearingRaceContactGeometry",
    "DIN7322010Results",
    "ForceAtLaminaGroupReportable",
    "ForceAtLaminaReportable",
    "FrictionModelForGyroscopicMoment",
    "InternalClearance",
    "ISO14179Settings",
    "ISO14179SettingsDatabase",
    "ISO14179SettingsPerBearingType",
    "ISO153122018Results",
    "ISOTR1417912001Results",
    "ISOTR141792001Results",
    "ISOTR1417922001Results",
    "LoadedAbstractSphericalRollerBearingStripLoadResults",
    "LoadedAngularContactBallBearingElement",
    "LoadedAngularContactBallBearingResults",
    "LoadedAngularContactBallBearingRow",
    "LoadedAngularContactThrustBallBearingElement",
    "LoadedAngularContactThrustBallBearingResults",
    "LoadedAngularContactThrustBallBearingRow",
    "LoadedAsymmetricSphericalRollerBearingElement",
    "LoadedAsymmetricSphericalRollerBearingResults",
    "LoadedAsymmetricSphericalRollerBearingRow",
    "LoadedAsymmetricSphericalRollerBearingStripLoadResults",
    "LoadedAxialThrustCylindricalRollerBearingDutyCycle",
    "LoadedAxialThrustCylindricalRollerBearingElement",
    "LoadedAxialThrustCylindricalRollerBearingResults",
    "LoadedAxialThrustCylindricalRollerBearingRow",
    "LoadedAxialThrustNeedleRollerBearingElement",
    "LoadedAxialThrustNeedleRollerBearingResults",
    "LoadedAxialThrustNeedleRollerBearingRow",
    "LoadedBallBearingDutyCycle",
    "LoadedBallBearingElement",
    "LoadedBallBearingRaceResults",
    "LoadedBallBearingResults",
    "LoadedBallBearingRow",
    "LoadedCrossedRollerBearingElement",
    "LoadedCrossedRollerBearingResults",
    "LoadedCrossedRollerBearingRow",
    "LoadedCylindricalRollerBearingDutyCycle",
    "LoadedCylindricalRollerBearingElement",
    "LoadedCylindricalRollerBearingResults",
    "LoadedCylindricalRollerBearingRow",
    "LoadedDeepGrooveBallBearingElement",
    "LoadedDeepGrooveBallBearingResults",
    "LoadedDeepGrooveBallBearingRow",
    "LoadedElement",
    "LoadedFourPointContactBallBearingElement",
    "LoadedFourPointContactBallBearingRaceResults",
    "LoadedFourPointContactBallBearingResults",
    "LoadedFourPointContactBallBearingRow",
    "LoadedMultiPointContactBallBearingElement",
    "LoadedNeedleRollerBearingElement",
    "LoadedNeedleRollerBearingResults",
    "LoadedNeedleRollerBearingRow",
    "LoadedNonBarrelRollerBearingDutyCycle",
    "LoadedNonBarrelRollerBearingResults",
    "LoadedNonBarrelRollerBearingRow",
    "LoadedNonBarrelRollerBearingStripLoadResults",
    "LoadedNonBarrelRollerElement",
    "LoadedRollerBearingElement",
    "LoadedRollerBearingResults",
    "LoadedRollerBearingRow",
    "LoadedRollerStripLoadResults",
    "LoadedRollingBearingRaceResults",
    "LoadedRollingBearingResults",
    "LoadedRollingBearingRow",
    "LoadedSelfAligningBallBearingElement",
    "LoadedSelfAligningBallBearingResults",
    "LoadedSelfAligningBallBearingRow",
    "LoadedSphericalRadialRollerBearingElement",
    "LoadedSphericalRollerBearingElement",
    "LoadedSphericalRollerRadialBearingResults",
    "LoadedSphericalRollerRadialBearingRow",
    "LoadedSphericalRollerRadialBearingStripLoadResults",
    "LoadedSphericalRollerThrustBearingResults",
    "LoadedSphericalRollerThrustBearingRow",
    "LoadedSphericalThrustRollerBearingElement",
    "LoadedTaperRollerBearingDutyCycle",
    "LoadedTaperRollerBearingElement",
    "LoadedTaperRollerBearingResults",
    "LoadedTaperRollerBearingRow",
    "LoadedThreePointContactBallBearingElement",
    "LoadedThreePointContactBallBearingResults",
    "LoadedThreePointContactBallBearingRow",
    "LoadedThrustBallBearingElement",
    "LoadedThrustBallBearingResults",
    "LoadedThrustBallBearingRow",
    "LoadedToroidalRollerBearingElement",
    "LoadedToroidalRollerBearingResults",
    "LoadedToroidalRollerBearingRow",
    "LoadedToroidalRollerBearingStripLoadResults",
    "MaximumStaticContactStress",
    "MaximumStaticContactStressDutyCycle",
    "MaximumStaticContactStressResultsAbstract",
    "MaxStripLoadStressObject",
    "PermissibleContinuousAxialLoadResults",
    "PowerRatingF1EstimationMethod",
    "PreloadFactorLookupTable",
    "ResultsAtRollerOffset",
    "RingForceAndDisplacement",
    "RollerAnalysisMethod",
    "RollingBearingFrictionCoefficients",
    "RollingBearingSpeedResults",
    "SMTRibStressResults",
    "StressAtPosition",
    "ThreePointContactInternalClearance",
    "TrackTruncationSafetyFactorResults",
)
